package SPVM::Error::System;

1;

=head1 Name

SPVM::Error::System - System Error

=head1 Usage

  use Error::System;

=head1 Description

C<Error::System> is the error class for system errors. The class id is C<2>.
